@@ -3,4 +3,5 @@ library("ggplot2")
 p <- ggplot(mtcars) +
      geom_point(aes(x = wt, y = mpg, colour = factor(gear))) +
      facet_wrap(~am)
-p + theme_solarized() + scale_colour_solarized()
+p + theme_solarized() +
+  scale_colour_solarized()
